require 'thor'
require 'erb'
require "redux_gen/version"
require "redux_gen/validations"
require "redux_gen/template"

module ReduxGen
  class CLI < Thor
    desc "new", "Create Redux components"
    def new(component, name)
      Validations.validate component
      Validations.validate_directory_for component
      Validations.validate_test_directory_for component
      make component, name
      make_test component, name
    end

    private

    def write_out(path, content)
      open(path, 'w') do |output|
        output.write content
      end
    end

    def make(component, name)
      path = Validations.component_path component, name
      template = Template.new(component, name).render
      write_out(path, template)
    end

    def make_test(component, name)
      test_path = Validations.test_path component, name
      test_template = Template.new(component, name, test: true).render
      write_out(test_path, test_template)
    end
  end
end
