module ReduxGen
  module Validations
    def self.validate component
      components = ["action", "component", "reducer", "middleware"]
      raise ArgumentError unless components.include? component
    end

    def self.directory component
      component == "middleware" ? component : "#{component}s"
    end

    def self.test_directory component
      "#{directory(component)}/tests"
    end

    def self.validate_directory_for component
      Dir.mkdir directory(component) unless Dir.exists? directory(component)
    end

    def self.validate_test_directory_for component
      unless Dir.exists? test_directory(component)
        Dir.mkdir test_directory(component)
      end
    end

    def self.component_path(component, name)
      "#{directory(component)}/#{sanitize(component, name)}.js"
    end

    def self.test_path(component, name)
      "#{directory(component)}/tests/#{sanitize(component, name)}.spec.js"
    end

    def self.sanitize component, name
      first = name.split.first
      rest = name.split[1..-1].map(&:capitalize).join
      (component == "component" ? first.capitalize : first) + rest
    end
  end
end
